package net.java.truelicense.ws.rs;

import net.java.truelicense.core.LicenseManagementException;

import javax.annotation.CheckForNull;
import java.security.GeneralSecurityException;

/**
 * Wraps a {@link LicenseManagementException} in order to decorate it with
 * additional meta data for generating an HTTP response.
 *
 * @author Christian Schlichtherle
 */
public final class LicenseConsumerServiceException
extends GeneralSecurityException {

    private final int status;

    /**
     * Constructs a license consumer service exception with the given HTTP
     * status code and its causing license management exception.
     *
     * @param status the HTTP status code.
     * @param cause the causing license management exception.
     * @see <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html">http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html</a>
     */
    LicenseConsumerServiceException(
            final int status,
            final @CheckForNull LicenseManagementException cause) {
        super(null == cause ? null : cause.getMessage(), cause);
        this.status = status;
    }

    /** Returns the HTTP status code. */
    public int getStatus() { return status; }
}
